window.Gleam.initSearch([{"doc":"pine","title":"pine","content":"# pine\n\n![](./pine.svg)\n\n[![Package Version](https://img.shields.io/hexpm/v/pine)](https://hex.pm/packages/timber)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/pine/)\n\n```sh\ngleam add pine\n```\n\n```gleam\nimport pine\n\npub fn main() {\n  // The defaults work out of the box.\n  // This will print a line to the console.\n  pine.new()\n    |&gt; pine.info(&quot;hello world!&quot;)\n  // info &lt;unix millis&gt; hello world!\n\n\n\n  // Pine is configurable!\n  pine.new()\n\n    // You can set the level.\n  |&gt; pine.set_level(pine.level_info())\n\n    // As well as the format.\n  |&gt; pine.set_format(pine.format_json())\n\n    // And finally, the transport!\n  |&gt; pine.set_transport(pine.transport_file(&quot;logs.txt&quot;))\n\n\n\n  // Different log functions are on the pine module.\n  pine.new()\n\n    // You have access to &quot;debug&quot; logs\n    |&gt; pine.debug(&quot;debug message&quot;)\n\n    // As well as &#39;info&#39; logs\n    |&gt; pine.info(&quot;info message&quot;)\n\n    // As well as &#39;warn&#39; logs\n    |&gt; pine.warn(&quot;warn message&quot;)\n\n    // As well as &#39;err&#39; logs\n    |&gt; pine.err(&quot;err message&quot;)\n\n\n  // You can add attributes to loggers as needed.\n  // This is especially useful for telemetry and tracing.\n  pine.new()\n\n    // Such as strings\n  |&gt; pine.with_string(&quot;version&quot;, &quot;v1.0.2&quot;)\n\n    // Or ints\n  |&gt; pine.with_int(&quot;page_views&quot;, 69)\n\n    // Or floats\n  |&gt; pine.with_float(&quot;opacity&quot;, 0.89)\n\n    // or bools\n  |&gt; pine.with_bool(&quot;checked_balance&quot;, False)\n\n    // then see them all in action\n  |&gt; pine.info(&quot;hello world!&quot;)\n  // info &lt;unix millis&gt; hello world! version=v1.0.2 page_views=69 opacity=0.89 checked_balance=False\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/pine&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"pine/attribute","title":"Attribute","content":"pub type Attribute {\n  StringAttribute(String, String)\n  IntAttribute(String, Int)\n  FloatAttribute(String, Float)\n  BoolAttribute(String, Bool)\n}\n\nStringAttribute(String, String)\n\n\nIntAttribute(String, Int)\n\n\nFloatAttribute(String, Float)\n\n\nBoolAttribute(String, Bool)\n\n\nSynonyms:\npine/attribute.Attribute\npine/attribute Attribute","url":"pine/attribute.html#Attribute"},{"doc":"pine/attribute","title":"pine/attribute","content":"","url":"pine/attribute.html"},{"doc":"pine/level","title":"Level","content":"pub opaque type Level\n Levels allow developers to categorize logs based on the type of information\n the log contains. Levels can determine which logs are actually processed.\n If the logger is configured with a _lower_ logging level than a particular\n log uses, then that log will not be processed.\n\n Levels are sequential in that each level contains the ones below it.\n Eg, a logger configured with the `Debug` level will log every message because\n `Debug` is the highest level. In contrast, a logger configured with the `Warn`\n level will not display `Info` or `Debug` logs.\n\nSynonyms:\npine/level.Level\npine/level Level","url":"pine/level.html#Level"},{"doc":"pine/level","title":"debug","content":"pub const debug: Level\n\nSynonyms:\npine/level.debug\npine/level debug","url":"pine/level.html#debug"},{"doc":"pine/level","title":"err","content":"pub const err: Level\n\nSynonyms:\npine/level.err\npine/level err","url":"pine/level.html#err"},{"doc":"pine/level","title":"info","content":"pub const info: Level\n\nSynonyms:\npine/level.info\npine/level info","url":"pine/level.html#info"},{"doc":"pine/level","title":"warn","content":"pub const warn: Level\n\nSynonyms:\npine/level.warn\npine/level warn","url":"pine/level.html#warn"},{"doc":"pine/level","title":"compare","content":"pub fn compare(left: Level, right: Level) -&gt; Order\n Compare two levels.\nSynonyms:\npine/level.compare\npine/level compare","url":"pine/level.html#compare"},{"doc":"pine/level","title":"from_int","content":"pub fn from_int(level: Int) -&gt; Result(Level, Nil)\n Transform an `Int` into it&#39;s corresonding log `Level`. Returns Ok if the int\n is a valid log leve, otherwise Error(Nil).\nSynonyms:\npine/level.from_int\npine/level from_int","url":"pine/level.html#from_int"},{"doc":"pine/level","title":"to_int","content":"pub fn to_int(level: Level) -&gt; Int\n Transform a log `Level` into it&#39;s corresonding int value.\nSynonyms:\npine/level.to_int\npine/level to_int","url":"pine/level.html#to_int"},{"doc":"pine/level","title":"to_string","content":"pub fn to_string(level: Level) -&gt; String\n Transform a log `Level` into it&#39;s corresonding int value.\nSynonyms:\npine/level.to_string\npine/level to_string","url":"pine/level.html#to_string"},{"doc":"pine/level","title":"pine/level","content":"","url":"pine/level.html"},{"doc":"pine/log","title":"Log","content":"pub type Log {\n  Log(\n    level: Level,\n    ts: Int,\n    msg: String,\n    attributes: List(Attribute),\n  )\n}\n\nLog(\n  level: Level,\n  ts: Int,\n  msg: String,\n  attributes: List(Attribute),\n)\n\n\nSynonyms:\npine/log.Log\npine/log Log","url":"pine/log.html#Log"},{"doc":"pine/log","title":"pine/log","content":"","url":"pine/log.html"},{"doc":"pine/format","title":"Formatter","content":"pub type Formatter =\n  fn(log.Log) -&gt; String\n\n\nSynonyms:\npine/format.Formatter\npine/format Formatter","url":"pine/format.html#Formatter"},{"doc":"pine/format","title":"json","content":"pub fn json(log: Log) -&gt; String\n\nSynonyms:\npine/format.json\npine/format json","url":"pine/format.html#json"},{"doc":"pine/format","title":"plain","content":"pub fn plain(log: Log) -&gt; String\n\nSynonyms:\npine/format.plain\npine/format plain","url":"pine/format.html#plain"},{"doc":"pine/format","title":"pine/format","content":"","url":"pine/format.html"},{"doc":"pine/transport","title":"Transport","content":"pub type Transport =\n  fn(String) -&gt; Nil\n\n\nSynonyms:\npine/transport.Transport\npine/transport Transport","url":"pine/transport.html#Transport"},{"doc":"pine/transport","title":"console","content":"pub fn console(payload: String) -&gt; Nil\n\nSynonyms:\npine/transport.console\npine/transport console","url":"pine/transport.html#console"},{"doc":"pine/transport","title":"file","content":"pub fn file(filename: String) -&gt; fn(String) -&gt; Nil\n\nSynonyms:\npine/transport.file\npine/transport file","url":"pine/transport.html#file"},{"doc":"pine/transport","title":"pine/transport","content":"","url":"pine/transport.html"},{"doc":"pine","title":"Logger","content":"pub opaque type Logger\n The logger type. This is opaque by default to prevent developers from relying\n on implementation details that may change.\n\nSynonyms:\npine.Logger\npine Logger","url":"pine.html#Logger"},{"doc":"pine","title":"debug","content":"pub fn debug(logger: Logger, msg: String) -&gt; Logger\n Creates a debug log.\nSynonyms:\npine.debug\npine debug","url":"pine.html#debug"},{"doc":"pine","title":"err","content":"pub fn err(logger: Logger, msg: String) -&gt; Logger\n Creates an err log.\nSynonyms:\npine.err\npine err","url":"pine.html#err"},{"doc":"pine","title":"format_json","content":"pub fn format_json() -&gt; fn(Log) -&gt; String\n Creates a formatter that outputs to `json`.\nSynonyms:\npine.format_json\npine format_json","url":"pine.html#format_json"},{"doc":"pine","title":"format_plain","content":"pub fn format_plain() -&gt; fn(Log) -&gt; String\n Creates a formatter that outputs to one line of plain text where each attribute is separated by a space.\nSynonyms:\npine.format_plain\npine format_plain","url":"pine.html#format_plain"},{"doc":"pine","title":"info","content":"pub fn info(logger: Logger, msg: String) -&gt; Logger\n Creates an info log.\nSynonyms:\npine.info\npine info","url":"pine.html#info"},{"doc":"pine","title":"level_debug","content":"pub fn level_debug() -&gt; Level\n The `debug` logging level.\nSynonyms:\npine.level_debug\npine level_debug","url":"pine.html#level_debug"},{"doc":"pine","title":"level_err","content":"pub fn level_err() -&gt; Level\n The `err` logging level.\nSynonyms:\npine.level_err\npine level_err","url":"pine.html#level_err"},{"doc":"pine","title":"level_info","content":"pub fn level_info() -&gt; Level\n The `info` logging level.\nSynonyms:\npine.level_info\npine level_info","url":"pine.html#level_info"},{"doc":"pine","title":"level_warn","content":"pub fn level_warn() -&gt; Level\n The `warn` logging level.\nSynonyms:\npine.level_warn\npine level_warn","url":"pine.html#level_warn"},{"doc":"pine","title":"new","content":"pub fn new() -&gt; Logger\n Create a new Logger.\n\n This uses the defaults of:\n   - plain format\n   - console transport\n   - debug level\nSynonyms:\npine.new\npine new","url":"pine.html#new"},{"doc":"pine","title":"set_format","content":"pub fn set_format(\n  logger: Logger,\n  new_format: fn(Log) -&gt; String,\n) -&gt; Logger\n Sets the logger to the given format.\nSynonyms:\npine.set_format\npine set_format","url":"pine.html#set_format"},{"doc":"pine","title":"set_level","content":"pub fn set_level(logger: Logger, new_level: Level) -&gt; Logger\n Sets the logger to the given level.\nSynonyms:\npine.set_level\npine set_level","url":"pine.html#set_level"},{"doc":"pine","title":"set_transport","content":"pub fn set_transport(\n  logger: Logger,\n  new_transport: fn(String) -&gt; Nil,\n) -&gt; Logger\n Sets the logger to the given transport.\nSynonyms:\npine.set_transport\npine set_transport","url":"pine.html#set_transport"},{"doc":"pine","title":"transport_console","content":"pub fn transport_console() -&gt; fn(String) -&gt; Nil\n Creates a transport that writes to the console.\nSynonyms:\npine.transport_console\npine transport_console","url":"pine.html#transport_console"},{"doc":"pine","title":"transport_file","content":"pub fn transport_file(filename: String) -&gt; fn(String) -&gt; Nil\n Creates a transport that writes the given file.\nSynonyms:\npine.transport_file\npine transport_file","url":"pine.html#transport_file"},{"doc":"pine","title":"warn","content":"pub fn warn(logger: Logger, msg: String) -&gt; Logger\n Creates a warn log.\nSynonyms:\npine.warn\npine warn","url":"pine.html#warn"},{"doc":"pine","title":"with_bool","content":"pub fn with_bool(\n  logger: Logger,\n  key: String,\n  value: Bool,\n) -&gt; Logger\n Adds a new &#39;bool&#39; attribute to a logger.\nSynonyms:\npine.with_bool\npine with_bool","url":"pine.html#with_bool"},{"doc":"pine","title":"with_float","content":"pub fn with_float(\n  logger: Logger,\n  key: String,\n  value: Float,\n) -&gt; Logger\n Adds a new &#39;float&#39; attribute to a logger.\nSynonyms:\npine.with_float\npine with_float","url":"pine.html#with_float"},{"doc":"pine","title":"with_int","content":"pub fn with_int(\n  logger: Logger,\n  key: String,\n  value: Int,\n) -&gt; Logger\n Adds a new &#39;int&#39; attribute to a logger.\nSynonyms:\npine.with_int\npine with_int","url":"pine.html#with_int"},{"doc":"pine","title":"with_string","content":"pub fn with_string(\n  logger: Logger,\n  key: String,\n  value: String,\n) -&gt; Logger\n Adds a new &#39;string&#39; attribute to a logger.\nSynonyms:\npine.with_string\npine with_string","url":"pine.html#with_string"},{"doc":"pine","title":"pine","content":"","url":"pine.html"}]);